@@ -97,14 +97,14 @@ void InsertHtmlDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(640, 480));
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myInsertHtmlDialogConfigGroupName));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myInsertHtmlDialogConfigGroupName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void InsertHtmlDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myInsertHtmlDialogConfigGroupName));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myInsertHtmlDialogConfigGroupName));
     KWindowConfig::saveWindowSize(windowHandle(), group);
 }
 }
